@@ -1,4 +1,5 @@
 from asdf.extension import ManifestExtension
+from astropy.utils import minversion
 
 from .converters.coordinates.angle import AngleConverter, LatitudeConverter, LongitudeConverter
 from .converters.coordinates.earth_location import EarthLocationConverter
@@ -17,6 +18,7 @@ from .converters.transform.mappings import IdentityConverter, RemapAxesConverter
 from .converters.transform.math_functions import MathFunctionsConverter
 from .converters.transform.polynomial import OrthoPolynomialConverter, PolynomialConverter
 from .converters.transform.projections import ProjectionConverter
+from .converters.transform.properties import CompoundBoundingBoxConverter, ModelBoundingBoxConverter
 from .converters.transform.rotations import Rotate3DConverter, RotationSequenceConverter
 from .converters.transform.spline import SplineConverter
 from .converters.transform.tabular import TabularConverter
@@ -360,8 +362,19 @@ TRANSFORM_CONVERTERS = [
     RotationSequenceConverter(),
     # astropy.modeling.tabular
     TabularConverter(),
+    # astropy.modeling.bounding_box
+    ModelBoundingBoxConverter(),
+    CompoundBoundingBoxConverter(),
 ]
 
+if minversion("astropy", "5.1.0"):
+    TRANSFORM_CONVERTERS.append(
+        SimpleTransformConverter(
+            ["tag:stsci.edu:asdf/transform/schechter1d-*"],
+            "astropy.modeling.powerlaws.Schechter1D",
+        )
+    )
+
 
 # The order here is important; asdf will prefer to use extensions
 # that occur earlier in the list.
